@@ -1,6 +1,6 @@
-acro_venv <- "r-acro-0.4.9"
-acro_package <- "acro==0.4.9"
-python_version <- ">=3.9"
+acro_venv <- "r-acro" #-0.4.11"
+acro_package <- "acro==0.4.11"
+python_version <- ">=3.10"
 
 
 #' Install acro
@@ -10,6 +10,7 @@ python_version <- ">=3.9"
 #'
 #' @return No return value, called for side effects
 
+#was envname= "r-acro"
 install_acro <- function(envname = "r-acro", ...) {
   # create Python virtual environment
   reticulate::virtualenv_create(
