@@ -6,7 +6,7 @@ test_that("acro_finalise without initialising ACRO object first", {
 test_that("acro_finalise works", {
   testthat::skip_on_cran()
   acro_init()
-  table = acro_crosstab(index=nursery_data[, c("health")], columns = nursery_data[, c("finance")])
+  table <- acro_crosstab(index = nursery_data[, c("health")], columns = nursery_data[, c("finance")])
   acro_finalise("test", "json")
   expect_true(dir.exists("test"))
 })
